@@ -11,7 +11,7 @@
  * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
  * for more details.
  *
- * RCSID $Id: alloc.c,v 1.2 2004-10-16 23:42:13 mcr Exp $
+ * RCSID $Id: alloc.c,v 1.2 2004/10/16 23:42:13 mcr Exp $
  */
 
 #include <stdlib.h>
@@ -20,6 +20,7 @@
 #include <dirent.h>
 #include <time.h>
 #include <sys/types.h>
+#include <unistd.h>
 
 #include <openswan.h>
 
@@ -29,6 +30,8 @@
 #define LEAK_DETECTIVE
 #include "oswalloc.h"
 
+int leak_detective = 0;
+
 const chunk_t empty_chunk = { NULL, 0 };
 
 exit_log_func_t exit_log_func;
@@ -89,6 +92,11 @@ void *alloc_bytes1(size_t size, const char *name, int leak_detective)
     }
 
     if (p == NULL) {
+	if(getenv("OPENSWAN_SNAPSHOT_MALLOC_FAIL")) {
+	    if(fork()==0) { /* in child */
+		abort();
+	    }
+	}
 	if(exit_log_func) {
 	    (*exit_log_func)("unable to malloc %lu bytes for %s"
 			     , (unsigned long) size, name);
