@@ -315,6 +315,7 @@ int addrtypeof(const ip_address *src);
 int subnettypeof(const ip_subnet *src);
 size_t addrlenof(const ip_address *src);
 size_t addrbytesptr(const ip_address *src, const unsigned char **dst);
+size_t addrbytesptr_write(ip_address *src, unsigned char **dst);
 size_t addrbytesof(const ip_address *src, unsigned char *dst, size_t dstlen);
 int masktocount(const ip_address *src);
 void networkof(const ip_subnet *src, ip_address *dst);
@@ -490,14 +491,9 @@ int
 goodmask(
 	struct in_addr mask
 );
-int
-masktobits(
-	struct in_addr mask
-);
-struct in_addr
-bitstomask(
-	int n
-);
+extern int masktobits(struct in_addr mask);
+extern struct in_addr  bitstomask(int n);
+extern struct in6_addr bitstomask6(int n);
 
 
 
