@@ -15,8 +15,6 @@
  * for more details.
  */
 
-char ipsec_xmit_c_version[] = "RCSID $Id: ipsec_xmit.c,v 1.20.2.13 2007-10-30 21:38:56 paul Exp $";
-
 #define __NO_VERSION__
 #include <linux/module.h>
 #ifndef AUTOCONF_INCLUDED
@@ -63,6 +61,7 @@ char ipsec_xmit_c_version[] = "RCSID $Id: ipsec_xmit.c,v 1.20.2.13 2007-10-30 21
 # include <net/tcp.h>		/* TCP options */
 #endif	/* MSS_HACK */
 
+#include "openswan/ipsec_kern24.h"
 #include "openswan/radij.h"
 #include "openswan/ipsec_life.h"
 #include "openswan/ipsec_xform.h"
@@ -80,8 +79,8 @@ char ipsec_xmit_c_version[] = "RCSID $Id: ipsec_xmit.c,v 1.20.2.13 2007-10-30 21
 #include "openswan/ipcomp.h"
 #endif /* CONFIG_KLIPS_IPCOMP */
 
-#include <pfkeyv2.h>
-#include <pfkey.h>
+#include <openswan/pfkeyv2.h>
+#include <openswan/pfkey.h>
 
 #include "openswan/ipsec_proto.h"
 #include "openswan/ipsec_alg.h"
@@ -647,7 +646,8 @@ ipsec_xmit_encap_once(struct ipsec_xmit_state *ixs)
 		
 		dat[len - authlen - 1] = ixs->iph->protocol;
 		ixs->iph->protocol = IPPROTO_ESP;
-#ifdef CONFIG_KLIPS_DEBUG
+
+#ifdef CONFIG_KLIPS_DEBUG		
 		if(debug_tunnel & DB_TN_ENCAP) {
 		        dmp("pre-encrypt", dat, len);
 		}
@@ -1061,12 +1061,11 @@ static int create_hold_eroute(struct eroute *origtrap,
 enum ipsec_xmit_value
 ipsec_xmit_encap_bundle(struct ipsec_xmit_state *ixs)
 {
-#ifdef CONFIG_KLIPS_ALG
 	struct ipsec_alg_enc *ixt_e = NULL;
 	struct ipsec_alg_auth *ixt_a = NULL;
 	int blocksize = 8;
-#endif
 	enum ipsec_xmit_value bundle_stat = IPSEC_XMIT_OK;
+	struct ipsec_sa *saved_ipsp;
  
 	ixs->newdst = ixs->orgdst = ixs->iph->daddr;
 	ixs->newsrc = ixs->orgsrc = ixs->iph->saddr;
@@ -1246,7 +1245,7 @@ ipsec_xmit_encap_bundle(struct ipsec_xmit_state *ixs)
 	 * How much headroom do we need to be able to apply
 	 * all the grouped transforms?
 	 */
-	ixs->ipsq = ixs->ipsp;	/* save the head of the ipsec_sa chain */
+	saved_ipsp = ixs->ipsp;	/* save the head of the ipsec_sa chain */
 	while (ixs->ipsp) {
 		if (debug_tunnel & DB_TN_XMIT) {
 		ixs->sa_len = KLIPS_SATOT(debug_tunnel, &ixs->ipsp->ips_said, 0, ixs->sa_txt, sizeof(ixs->sa_txt));
@@ -1259,7 +1258,7 @@ ipsec_xmit_encap_bundle(struct ipsec_xmit_state *ixs)
 		}
 
 		/* If it is in larval state, drop the packet, we cannot process yet. */
-		if(ixs->ipsp->ips_state == SADB_SASTATE_LARVAL) {
+		if(ixs->ipsp->ips_state == K_SADB_SASTATE_LARVAL) {
 			KLIPS_PRINT(debug_tunnel & DB_TN_XMIT,
 				    "klips_debug:ipsec_xmit_encap_bundle: "
 				    "ipsec_sa in larval state for SA:<%s%s%s> %s, cannot be used yet, dropping packet.\n",
@@ -1272,7 +1271,7 @@ ipsec_xmit_encap_bundle(struct ipsec_xmit_state *ixs)
 			goto cleanup;
 		}
 
-		if(ixs->ipsp->ips_state == SADB_SASTATE_DEAD) {
+		if(ixs->ipsp->ips_state == K_SADB_SASTATE_DEAD) {
 			KLIPS_PRINT(debug_tunnel & DB_TN_XMIT,
 				    "klips_debug:ipsec_xmit_encap_bundle: "
 				    "ipsec_sa in dead state for SA:<%s%s%s> %s, can no longer be used, dropping packet.\n",
@@ -1291,7 +1290,7 @@ ipsec_xmit_encap_bundle(struct ipsec_xmit_state *ixs)
 				    "replay window counter rolled for SA:<%s%s%s> %s, packet dropped, expiring SA.\n",
 				    IPS_XFORM_NAME(ixs->ipsp),
 				    ixs->sa_len ? ixs->sa_txt : " (error)");
-			ipsec_sa_delchain(ixs->ipsp);
+			ipsec_sa_rm(ixs->ipsp);
 			ixs->stats->tx_errors++;
 			bundle_stat = IPSEC_XMIT_REPLAYROLLED;
 			goto cleanup;
@@ -1319,7 +1318,7 @@ ipsec_xmit_encap_bundle(struct ipsec_xmit_state *ixs)
 		   ipsec_lifetime_check(&ixs->ipsp->ips_life.ipl_packets, "packets",ixs->sa_txt,
 					ipsec_life_countbased, ipsec_outgoing, ixs->ipsp) == ipsec_life_harddied) {
 				
-			ipsec_sa_delchain(ixs->ipsp);
+			ipsec_sa_rm(ixs->ipsp);
 			ixs->stats->tx_errors++;
 			bundle_stat = IPSEC_XMIT_LIFETIMEFAILED;
 			goto cleanup;
@@ -1439,7 +1438,7 @@ ipsec_xmit_encap_bundle(struct ipsec_xmit_state *ixs)
 		ixs->max_tailroom += ixs->tailroom;
 		ixs->pyldsz += (ixs->headroom + ixs->tailroom);
 	}
-	ixs->ipsp = ixs->ipsq;	/* restore the head of the ipsec_sa chain */
+	ixs->ipsp = saved_ipsp;	/* restore the head of the ipsec_sa chain */
 		
 	KLIPS_PRINT(debug_tunnel & DB_TN_CROUT,
 		    "klips_debug:ipsec_xmit_encap_bundle: "
@@ -1707,7 +1706,8 @@ ipsec_xmit_encap_bundle(struct ipsec_xmit_state *ixs)
 			    "head,tailroom: %d,%d after allocation\n",
 			    skb_headroom(ixs->skb), skb_tailroom(ixs->skb));
 	}
-#ifdef CONFIG_KLIPS_DEBUG		
+		
+#ifdef CONFIG_KLIPS_DEBUG
 	if(debug_tunnel & DB_TN_ENCAP) {
 		ipsec_print_ip(ixs->iph);
 	}
@@ -1720,6 +1720,7 @@ ipsec_xmit_encap_bundle(struct ipsec_xmit_state *ixs)
 		enum ipsec_xmit_value encap_stat = IPSEC_XMIT_OK;
 
 		encap_stat = ipsec_xmit_encap_once(ixs);
+
 #ifdef CONFIG_KLIPS_DEBUG
 		if(debug_tunnel & DB_TN_ENCAP) {
 			ipsec_print_ip(ixs->iph);
@@ -1747,7 +1748,7 @@ ipsec_xmit_encap_bundle(struct ipsec_xmit_state *ixs)
 
 /*
  * $Log: ipsec_xmit.c,v $
- * Revision 1.20.2.13  2007-10-30 21:38:56  paul
+ * Revision 1.20.2.13  2007/10/30 21:38:56  paul
  * Use skb_tail_pointer [dhr]
  *
  * Revision 1.20.2.12  2007-10-28 00:26:03  paul
