@@ -13,7 +13,7 @@
  * for more details.
  */
 
-char tncfg_c_version[] = "RCSID $Id: lwdnsq.c,v 1.19.8.2 2006-08-16 21:24:13 mcr Exp $";
+char tncfg_c_version[] = "RCSID $Id: lwdnsq.c,v 1.23 2005/08/26 19:13:48 mcr Exp $";
 
 
 #include <stdio.h>
@@ -200,7 +200,7 @@ static int cmdread(dnskey_glob *gs,
 		   char  *buf,
 		   int    len)
 {
-	unsigned char *nl;
+	char *nl;
 	int   cmdlen;
 
 	cmdlen=0;
@@ -217,11 +217,11 @@ static int cmdread(dnskey_glob *gs,
 		gs->cmdloc=0;
 		return 0;
 	}
-	memcpy(gs->cmdbuf+gs->cmdloc, buf, len);
+	memcpy((unsigned char *)gs->cmdbuf+gs->cmdloc, (unsigned char *)buf, len);
 	gs->cmdloc+=len;
 	gs->cmdbuf[gs->cmdloc]='\0';
 
-	while((nl = strchr(gs->cmdbuf, '\n')) != NULL) {
+	while((nl = strchr((char *)gs->cmdbuf, '\n')) != NULL) {
 		/* found a newline, so turn it into a \0, and process the
 		 * command, and then we will pull the rest of the buffer
 		 * up.
@@ -229,10 +229,10 @@ static int cmdread(dnskey_glob *gs,
 		*nl='\0';
 		cmdlen= nl - gs->cmdbuf +1;
 
-		cmdparse(gs, gs->cmdbuf);
+		cmdparse(gs, (char *)gs->cmdbuf);
 
 		gs->cmdloc -= cmdlen;
-		memmove(gs->cmdbuf, gs->cmdbuf+cmdlen, gs->cmdloc);
+		memmove((unsigned char *)gs->cmdbuf, (unsigned char *)gs->cmdbuf+cmdlen, gs->cmdloc);
 	}
 	return 1;
 }
@@ -551,13 +551,6 @@ main(int argc, char *argv[])
 	
 /*
  * $Log: lwdnsq.c,v $
- * Revision 1.19.8.2  2006-08-16 21:24:13  mcr
- * fix signed/unsigned char problem.
- *
- * Revision 1.19.8.1  2006/08/16 17:29:11  mcr
- * back ported #public to 2.4 branch for luck in tracking down loop in
- * lwdnsq. Added some loop checking code as well.
- *
  * Revision 1.23  2005/08/26 19:13:48  mcr
  * 	fixed attempt to write an #ifdef.
  *
