@@ -1980,6 +1980,7 @@ main_inI3_outR3_tail(struct msg_digest *md
     pb_stream r_id_pbs;	/* ID Payload; also used for hash calculation */
     cert_t mycert;
     bool send_cert;
+    unsigned int np;
 
     /* ID and HASH_I or SIG_I in
      * Note: this may switch the connection being used!
@@ -2072,6 +2073,12 @@ main_inI3_outR3_tail(struct msg_digest *md
     }
 #endif
 
+    /* IKEv2 NOTIFY payload */
+    np = ISAKMP_NEXT_NONE;
+    if(st->st_connection->policy & POLICY_IKEV2_ALLOW) {
+	np = ISAKMP_NEXT_VID;
+    }
+
     /* HASH_R or SIG_R out */
     {
 	u_char hash_val[MAX_DIGEST_LEN];
@@ -2080,7 +2087,7 @@ main_inI3_outR3_tail(struct msg_digest *md
 	if (auth_payload == ISAKMP_NEXT_HASH)
 	{
 	    /* HASH_R out */
-	    if (!out_generic_raw(ISAKMP_NEXT_NONE, &isakmp_hash_desc, &md->rbody
+	    if (!out_generic_raw(np, &isakmp_hash_desc, &md->rbody
 	    , hash_val, hash_len, "HASH_R"))
 		return STF_INTERNAL_ERROR;
 	}
@@ -2097,12 +2104,18 @@ main_inI3_outR3_tail(struct msg_digest *md
 		return STF_FAIL + AUTHENTICATION_FAILED;
 	    }
 
-	    if (!out_generic_raw(ISAKMP_NEXT_NONE, &isakmp_signature_desc
+	    if (!out_generic_raw(np, &isakmp_signature_desc
 	    , &md->rbody, sig_val, sig_len, "SIG_R"))
 		return STF_INTERNAL_ERROR;
 	}
     }
 
+    if(st->st_connection->policy & POLICY_IKEV2_ALLOW) {
+	if(!out_vid(ISAKMP_NEXT_NONE, &md->rbody, VID_MISC_IKEv2))
+	    return STF_INTERNAL_ERROR;
+    }
+
+
     /* encrypt message, sans fixed part of header */
 
     if (!encrypt_message(&md->rbody, st))
@@ -2193,7 +2206,27 @@ main_inR3_tail(struct msg_digest *md
     
     update_iv(st);	/* finalize our Phase 1 IV */
 
-    
+    if(md->ikev2) {
+	/* 
+	 * We cannot use POLICY_IKEV2_ALLOW here, since this will
+	 * cause two IKEv2 capable but not ikev2= configured endpoints
+	 * to falsely detect a bid down attack.
+	 * Also, only the side that proposed IKEv2 can figure out there
+	 * was a bid down attack to begin with. The side that did not propose
+	 * cannot distinguish attack from regular ikev1 operation.
+	 * if(st->st_connection->policy & POLICY_IKEV2_ALLOW) {
+	 */
+	if(st->st_connection->policy & POLICY_IKEV2_PROPOSE) {
+	    openswan_log("Bid-down to IKEv1 attack detected, attempting to rekey connection with IKEv2");
+	    st->st_connection->failed_ikev2 = FALSE;
+	    
+	    /* schedule an event to do this as soon as possible */
+	    md->event_already_set = TRUE;
+	    st->st_rekeytov2 = TRUE;
+	    delete_event(st);
+	    event_schedule(EVENT_SA_REPLACE, 0, st);
+	}
+    }
 
     return STF_OK;
 }
