@@ -506,7 +506,7 @@ stf_status ikev2parent_inI1outR1(struct msg_digest *md)
 	 */
 	DBG_log("no connection found\n");
 	//SEND_NOTIFICATION(NO_PROPOSAL_CHOSEN);
-	return STF_FAIL;
+	return STF_FAIL + NO_PROPOSAL_CHOSEN;
     }
 	
 
@@ -529,6 +529,7 @@ stf_status ikev2parent_inI1outR1(struct msg_digest *md)
     /* check,as a responder, are we under dos attack or not 
 	 * if yes go to 6 message exchange mode. it is a config option for now.
 	 * TBD set force_busy dynamically
+	 * Paul: Can we check for STF_TOOMUCHCRYPTO ?
 	 */ 
 	if(force_busy == TRUE) 
 	{ 
@@ -558,7 +559,7 @@ stf_status ikev2parent_inI1outR1(struct msg_digest *md)
 			if(memcmp(blob.ptr, dcookie, SHA1_DIGEST_SIZE)!=0) {
 				openswan_log("mismatch in DOS COOKIE,send a new one");
 				SEND_NOTIFICATION_AA(COOKIE, &dc); 
-				return STF_FAIL;
+				return STF_FAIL + INVALID_COOKIE;
 			}
 			DBG(DBG_CONTROLMORE
 	            ,DBG_log("dcookie received match with computed one"));
@@ -823,6 +824,20 @@ stf_status ikev2parent_inR1outI2(struct msg_digest *md)
 		return ikev2_parent_outI1_common(md, st);  
     }
 
+    /*
+     * If we did not get a KE payload, we cannot continue. There * should be
+     * a Notify telling us why. We inform the user, but continue to try this
+     * connection via regular retransmit intervals.
+     */
+    if( md->chain[ISAKMP_NEXT_v2N]  && (md->chain[ISAKMP_NEXT_v2KE] == NULL)) {
+	const char *from_state_name = enum_name(&state_names, st->st_state);
+	openswan_log("%s: received %s"
+		, from_state_name
+		, enum_name(&notification_names, 
+			md->chain[ISAKMP_NEXT_v2N]->payload.v2n.isan_type));
+               return STF_FAIL + NO_PROPOSAL_CHOSEN;
+       }
+
     /*
      * the responder sent us back KE, Gr, Nr, and it's our time to calculate
      * the shared key values.
@@ -831,12 +846,6 @@ stf_status ikev2parent_inR1outI2(struct msg_digest *md)
     DBG(DBG_CONTROLMORE
 	, DBG_log("ikev2 parent inR1: calculating g^{xy} in order to send I2"));
 
-    if(st->st_gr.len == 0) {
-	/* Remote end did not send us Gr in R1 - likely a NOTIFY message */
-	openswan_log("No responder Gr found in R1 packet");
-	return PAYLOAD_MALFORMED;
-    }
- 
     /* KE in */
     keyex_pbs = &md->chain[ISAKMP_NEXT_v2KE]->pbs;
     RETURN_STF_FAILURE(accept_KE(&st->st_gr, "Gr", st->st_oakley.group, keyex_pbs));
@@ -1159,11 +1168,11 @@ static stf_status ikev2_send_auth(struct connection *c
     
     if(c->policy & POLICY_RSASIG) {
 	if(!ikev2_calculate_rsa_sha1(pst, role, idhash_out, &a_pbs))
-	    return STF_FATAL;
+	    return STF_FATAL + AUTHENTICATION_FAILED;
 	
     } else if(c->policy & POLICY_PSK) {
 	if(!ikev2_calculate_psk_auth(pst, role, idhash_out, &a_pbs))
-	return STF_FAIL;
+	return STF_FAIL + AUTHENTICATION_FAILED;
     } 
     
     close_output_pbs(&a_pbs);
