@@ -56,9 +56,10 @@ struct pcr_kenonce {
 #define DHCALC_SIZE 2560
 struct pcr_skeyid_q {
   /* inputs */
-  u_int16_t     oakley_group;
-  oakley_auth_t auth;	            
-  oakley_hash_t hash;               
+    u_int16_t     oakley_group;
+    oakley_auth_t auth;	            
+    oakley_hash_t integ_hash;
+    oakley_hash_t prf_hash;               
   enum phase1_role init;
   size_t        keysize;     /* of encryptor */
   wire_chunk_t gi;
@@ -88,6 +89,22 @@ struct pcr_skeyid_r {
   unsigned char space[DHCALC_SIZE];
 };
 
+struct pcr_skeycalc_v2 {
+    /* outputs */
+    wire_chunk_t shared;
+    wire_chunk_t skeyseed;        /* output */
+    wire_chunk_t skeyid_d;        /* output */
+    wire_chunk_t skeyid_ai;       /* output */
+    wire_chunk_t skeyid_ar;       /* output */
+    wire_chunk_t skeyid_ei;       /* output */
+    wire_chunk_t skeyid_er;       /* output */
+    wire_chunk_t skeyid_pi;       /* output */
+    wire_chunk_t skeyid_pr;       /* output */
+
+    wire_chunk_t thespace;
+    unsigned char space[DHCALC_SIZE];
+};
+
 
 #define space_chunk_ptr(SPACE, wire) ((void *)&((SPACE)[(wire)->start]))
 #define wire_chunk_ptr(k, wire) space_chunk_ptr((k)->space, wire)
@@ -101,8 +118,6 @@ struct pcr_skeyid_r {
     memcpy(wire_chunk_ptr(ctner, w), c->ptr, c->len);	\
   } while(0)
 
-
-
 struct pluto_crypto_req {
   size_t                     pcr_len;
 
@@ -111,9 +126,10 @@ struct pluto_crypto_req {
   enum crypto_importance     pcr_pcim;
   int                        pcr_slot;
   union {
-    struct pcr_kenonce kn;
-    struct pcr_skeyid_q  dhq;
-    struct pcr_skeyid_r  dhr;
+      struct pcr_kenonce      kn;
+      struct pcr_skeyid_q     dhq;
+      struct pcr_skeyid_r     dhr;
+      struct pcr_skeycalc_v2  dhv2;
   } pcr_d;
 };
 
@@ -189,9 +205,43 @@ extern stf_status start_dh_secret(struct pluto_crypto_req_cont *cn
 extern void finish_dh_secret(struct state *st,
 			     struct pluto_crypto_req *r);
 
+extern stf_status start_dh_v2(struct pluto_crypto_req_cont *cn
+			      , struct state *st
+			      , enum crypto_importance importance
+			      , enum phase1_role init       /* TRUE=g_init,FALSE=g_r */
+			      , u_int16_t oakley_group2);
+
+extern void finish_dh_v2(struct state *st,
+			 struct pluto_crypto_req *r);
 
 extern void calc_dh_iv(struct pluto_crypto_req *r);
 extern void calc_dh(struct pluto_crypto_req *r);
+extern void calc_dh_v2(struct pluto_crypto_req *r);
+
+extern void unpack_KE(struct state *st
+		      , struct pluto_crypto_req *r
+		      , chunk_t *g);
+extern void unpack_nonce(chunk_t *n, struct pluto_crypto_req *r);
+
+
+static inline void clonetowirechunk(wire_chunk_t  *thespace,
+			     unsigned char *space,
+			     wire_chunk_t *wiretarget,
+			     const void   *origdat,
+			     const size_t  origlen)
+{
+    char *gip;
+    pluto_crypto_allocchunk(thespace, wiretarget, origlen);
+
+    gip = space_chunk_ptr(space, wiretarget);
+    memcpy(gip, origdat, origlen);
+}
+
+static inline void pcr_init(struct pluto_crypto_req *r)
+{
+    r->pcr_d.kn.thespace.start = 0;
+    r->pcr_d.kn.thespace.len   = sizeof(r->pcr_d.kn.space);
+}
 
 #endif /* _PLUTO_CRYPT_H */
 
