@@ -7,8 +7,9 @@ TEST_TYPE=ctltest
 TESTNAME=saref-alloc-02
 TESTHOST=east
 
-REFCONSOLEOUTPUT=fewallocs.txt
+REF_CONSOLE_OUTPUT=fewallocs.txt
 REF_CONSOLE_FIXUPS="kern-list-fixups.sed nocr.sed"
+REF_CONSOLE_FIXUPS="$REF_CONSOLE_FIXUPS script-only.sed"
 REF_CONSOLE_FIXUPS="$REF_CONSOLE_FIXUPS east-prompt-splitline.pl"
 REF_CONSOLE_FIXUPS="$REF_CONSOLE_FIXUPS klips-debug-sanitize.sed"
 REF_CONSOLE_FIXUPS="$REF_CONSOLE_FIXUPS pfkey-sanitize.sed"
