@@ -1,5 +1,8 @@
 : ==== start ====
 TESTNAME=interop-ikev2-strongswan-01-noconn
+PLUTO_EVENT_RETRANSMIT_DELAY=3
+PLUTO_MAXIMUM_RETRANSMISSIONS_INITIAL=4
+
 source /testing/pluto/bin/westnlocal.sh
 
 # make sure that clear text does not get through
